package xyz.lychee.lagfixer.libs.adventure.chat;

import java.security.SecureRandom;
import java.time.Instant;
import xyz.lychee.lagfixer.libs.adventure.identity.Identity;
import xyz.lychee.lagfixer.libs.adventure.text.Component;
import xyz.lychee.lagfixer.libs.annotations.NotNull;
import xyz.lychee.lagfixer.libs.annotations.Nullable;

final class SignedMessageImpl implements SignedMessage {
   static final SecureRandom RANDOM = new SecureRandom();
   private final Instant instant = Instant.now();
   private final long salt;
   private final String message;
   private final Component unsignedContent;

   SignedMessageImpl(final String message, final Component unsignedContent) {
      this.salt = RANDOM.nextLong();
      this.message = message;
      this.unsignedContent = unsignedContent;
   }

   public @NotNull Instant timestamp() {
      return this.instant;
   }

   public long salt() {
      return this.salt;
   }

   public SignedMessage.Signature signature() {
      return null;
   }

   public @Nullable Component unsignedContent() {
      return this.unsignedContent;
   }

   public @NotNull String message() {
      return this.message;
   }

   public @NotNull Identity identity() {
      return Identity.nil();
   }

   static final class SignatureImpl implements SignedMessage.Signature {
      final byte[] signature;

      SignatureImpl(final byte[] signature) {
         this.signature = signature;
      }

      public byte[] bytes() {
         return this.signature;
      }
   }
}
